clear all

cd C:\Users\Sandro\Desktop\Data_Archive


********************************
***** TABLE 1: Panel Regressions
********************************

***Load data
use "data_formatting\yearly_dataset.dta", clear

* Drop Eastern-German, Non-German, Females between 60 and 64
* as well as Eastern-German, German, Males and Females between 55 and 59

drop if group == 10 | group == 42 | group == 31
***



* column 1: not-weighted-overall-regression
xtreg c_ L.ABLQ L.c_, fe rob
nlcom _b[L.ABLQ]/(1-_b[L.c_])


* column 2: weighted-overall-regression
areg c_ L.ABLQ L.c_ [aweight=Bev_], absorb(group) rob
nlcom _b[L.ABLQ]/(1-_b[L.c_])


* column 3: added workers only

preserve
drop if added_dummy==0

areg c_ L.ABLQ L.c_ [aweight=Bev_], absorb(group) rob

nlcom _b[L.ABLQ]/(1-_b[L.c_])

restore


* column 4: discouraged workers only
preserve
drop if reserve_dummy==0

areg c_ L.ABLQ L.c_ [aweight=Bev_], absorb(group) rob

nlcom _b[L.ABLQ]/(1-_b[L.c_])

restore



*****************************************
***** TABLE 2: Disaggregated coefficients
*****************************************

***Load data
use data_formatting\lfpr_signi_testing.dta, clear
merge n:1 date using "data_formatting\unemployment_rate_yearly.dta"
drop _merge
rename UR ABLQ
tsset date
***


reg	c_W_D_M_15_19	L.c_W_D_M_15_19	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_M_15_19	])
reg	c_W_D_M_20_24	L.c_W_D_M_20_24	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_M_20_24	])	
reg	c_W_D_M_25_29	L.c_W_D_M_25_29	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_M_25_29	])	
reg	c_W_D_M_30_34	L.c_W_D_M_30_34	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_M_30_34	])	
reg	c_W_D_M_35_39	L.c_W_D_M_35_39	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_M_35_39	])	
reg	c_W_D_M_40_44	L.c_W_D_M_40_44	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_M_40_44	])	
reg	c_W_D_M_45_49	L.c_W_D_M_45_49	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_M_45_49	])	
reg	c_W_D_M_50_54	L.c_W_D_M_50_54	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_M_50_54	])	
reg	c_W_D_M_55_59	L.c_W_D_M_55_59	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_M_55_59	])	
reg	c_W_D_M_60_64	L.c_W_D_M_60_64	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_M_60_64	])	

				
reg	c_W_D_F_15_19	L.c_W_D_F_15_19	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_F_15_19	])	
reg	c_W_D_F_20_24	L.c_W_D_F_20_24	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_F_20_24	])	
reg	c_W_D_F_25_29	L.c_W_D_F_25_29	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_F_25_29	])	
reg	c_W_D_F_30_34	L.c_W_D_F_30_34	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_F_30_34	])	
reg	c_W_D_F_35_39	L.c_W_D_F_35_39	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_F_35_39	])	
reg	c_W_D_F_40_44	L.c_W_D_F_40_44	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_F_40_44	])	
reg	c_W_D_F_45_49	L.c_W_D_F_45_49	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_F_45_49	])	
reg	c_W_D_F_50_54	L.c_W_D_F_50_54	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_F_50_54	])	
reg	c_W_D_F_55_59	L.c_W_D_F_55_59	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_F_55_59	])	
reg	c_W_D_F_60_64	L.c_W_D_F_60_64	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_D_F_60_64	])	

				
				
reg	c_W_A_M_15_19	L.c_W_A_M_15_19	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_M_15_19	])	
reg	c_W_A_M_20_24	L.c_W_A_M_20_24	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_M_20_24	])	
reg	c_W_A_M_25_29	L.c_W_A_M_25_29	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_M_25_29	])	
reg	c_W_A_M_30_34	L.c_W_A_M_30_34	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_M_30_34	])	
reg	c_W_A_M_35_39	L.c_W_A_M_35_39	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_M_35_39	])	
reg	c_W_A_M_40_44	L.c_W_A_M_40_44	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_M_40_44	])	
reg	c_W_A_M_45_49	L.c_W_A_M_45_49	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_M_45_49	])	
reg	c_W_A_M_50_54	L.c_W_A_M_50_54	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_M_50_54	])	
reg	c_W_A_M_55_59	L.c_W_A_M_55_59	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_M_55_59	])	
reg	c_W_A_M_60_64	L.c_W_A_M_60_64	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_M_60_64	])	

				
				
reg	c_W_A_F_15_19	L.c_W_A_F_15_19	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_F_15_19	])	
reg	c_W_A_F_20_24	L.c_W_A_F_20_24	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_F_20_24	])	
reg	c_W_A_F_25_29	L.c_W_A_F_25_29	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_F_25_29	])	
reg	c_W_A_F_30_34	L.c_W_A_F_30_34	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_F_30_34	])	
reg	c_W_A_F_35_39	L.c_W_A_F_35_39	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_F_35_39	])	
reg	c_W_A_F_40_44	L.c_W_A_F_40_44	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_F_40_44	])	
reg	c_W_A_F_45_49	L.c_W_A_F_45_49	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_F_45_49	])	
reg	c_W_A_F_50_54	L.c_W_A_F_50_54	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_F_50_54	])	
reg	c_W_A_F_55_59	L.c_W_A_F_55_59	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_F_55_59	])	
reg	c_W_A_F_60_64	L.c_W_A_F_60_64	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_W_A_F_60_64	])	

				
reg	c_O_D_M_15_19	L.c_O_D_M_15_19	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_M_15_19	])	
reg	c_O_D_M_20_24	L.c_O_D_M_20_24	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_M_20_24	])	
reg	c_O_D_M_25_29	L.c_O_D_M_25_29	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_M_25_29	])	
reg	c_O_D_M_30_34	L.c_O_D_M_30_34	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_M_30_34	])	
reg	c_O_D_M_35_39	L.c_O_D_M_35_39	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_M_35_39	])	
reg	c_O_D_M_40_44	L.c_O_D_M_40_44	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_M_40_44	])	
reg	c_O_D_M_45_49	L.c_O_D_M_45_49	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_M_45_49	])	
reg	c_O_D_M_50_54	L.c_O_D_M_50_54	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_M_50_54	])	
 	
reg	c_O_D_M_60_64	L.c_O_D_M_60_64	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_M_60_64	])	
	


				
reg	c_O_D_F_15_19	L.c_O_D_F_15_19	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_F_15_19	])	
reg	c_O_D_F_20_24	L.c_O_D_F_20_24	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_F_20_24	])	
reg	c_O_D_F_25_29	L.c_O_D_F_25_29	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_F_25_29	])	
reg	c_O_D_F_30_34	L.c_O_D_F_30_34	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_F_30_34	])	
reg	c_O_D_F_35_39	L.c_O_D_F_35_39	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_F_35_39	])	
reg	c_O_D_F_40_44	L.c_O_D_F_40_44	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_F_40_44	])	
reg	c_O_D_F_45_49	L.c_O_D_F_45_49	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_F_45_49	])	
reg	c_O_D_F_50_54	L.c_O_D_F_50_54	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_F_50_54	])	

reg	c_O_D_F_60_64	L.c_O_D_F_60_64	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_D_F_60_64	])	

				
				
reg	c_O_A_M_15_19	L.c_O_A_M_15_19	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_M_15_19	])	
reg	c_O_A_M_20_24	L.c_O_A_M_20_24	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_M_20_24	])	
reg	c_O_A_M_25_29	L.c_O_A_M_25_29	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_M_25_29	])	
reg	c_O_A_M_30_34	L.c_O_A_M_30_34	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_M_30_34	])	
reg	c_O_A_M_35_39	L.c_O_A_M_35_39	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_M_35_39	])	
reg	c_O_A_M_40_44	L.c_O_A_M_40_44	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_M_40_44	])	
reg	c_O_A_M_45_49	L.c_O_A_M_45_49	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_M_45_49	])	
reg	c_O_A_M_50_54	L.c_O_A_M_50_54	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_M_50_54	])	
reg	c_O_A_M_55_59	L.c_O_A_M_55_59	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_M_55_59	])	
reg	c_O_A_M_60_64	L.c_O_A_M_60_64	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_M_60_64	])	

				
				
reg	c_O_A_F_15_19	L.c_O_A_F_15_19	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_F_15_19	])	
reg	c_O_A_F_20_24	L.c_O_A_F_20_24	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_F_20_24	])	
reg	c_O_A_F_25_29	L.c_O_A_F_25_29	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_F_25_29	])	
reg	c_O_A_F_30_34	L.c_O_A_F_30_34	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_F_30_34	])	
reg	c_O_A_F_35_39	L.c_O_A_F_35_39	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_F_35_39	])	
reg	c_O_A_F_40_44	L.c_O_A_F_40_44	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_F_40_44	])	
reg	c_O_A_F_45_49	L.c_O_A_F_45_49	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_F_45_49	])	
reg	c_O_A_F_50_54	L.c_O_A_F_50_54	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_F_50_54	])	
reg	c_O_A_F_55_59	L.c_O_A_F_55_59	L.ABLQ	,rob
	nlcom _b[L.ABLQ]/(1-_b[	L.c_O_A_F_55_59	])	


	
************************************
***** TABLE 3: Asymmetry Regressions
***** in up and downturns
************************************

***Load data
use "data_formatting\yearly_dataset.dta", clear

* Drop Eastern-German, Non-German, Females between 60 and 64
* as well as Eastern-German, German, Males and Females between 55 and 59

drop if group == 10 | group == 42 | group == 31
***

gen dummy_d=0
replace dummy_d=1 if d.ABLQ>0
gen dummy_u=1-dummy_d

gen intakt_d= dummy_d * ABLQ
gen intakt_u= dummy_u * ABLQ

* column 1: All discouraged worker groups
preserve
drop if reserve_dummy==0 
areg c_ L.intakt_d L.intakt_u L.c_  [aweight=Bev_], absorb(group) rob 
nlcom _b[L.intakt_d]/(1-_b[L.c_])
nlcom _b[L.intakt_u]/(1-_b[L.c_])
nlcom (_b[L.intakt_d]/(1-_b[L.c_])) - (_b[L.intakt_u]/(1-_b[L.c_]))
restore

* column 2: Young only

preserve
drop if reserve_dummy==0
drop if dummy_young == 0
areg c_ L.intakt_d L.intakt_u L.c_ [aweight=Bev_], absorb(group) rob
nlcom _b[L.intakt_d]/(1-_b[L.c_])
nlcom _b[L.intakt_u]/(1-_b[L.c_])
nlcom (_b[L.intakt_d]/(1-_b[L.c_])) - (_b[L.intakt_u]/(1-_b[L.c_]))
restore

* column 3: Medium aged only

preserve
drop if reserve_dummy==0
drop if dummy_medium == 0
areg c_ L.intakt_d L.intakt_u L.c_ [aweight=Bev_], absorb(group) rob
nlcom _b[L.intakt_d]/(1-_b[L.c_])
nlcom _b[L.intakt_u]/(1-_b[L.c_])
nlcom (_b[L.intakt_d]/(1-_b[L.c_])) - (_b[L.intakt_u]/(1-_b[L.c_]))
restore

* column 4: Old only

preserve
drop if reserve_dummy==0
drop if dummy_old == 0
areg c_ L.intakt_d L.intakt_u L.c_ [aweight=Bev_], absorb(group) rob
nlcom _b[L.intakt_d]/(1-_b[L.c_])
nlcom _b[L.intakt_u]/(1-_b[L.c_])
nlcom (_b[L.intakt_d]/(1-_b[L.c_])) - (_b[L.intakt_u]/(1-_b[L.c_]))
restore



********************************
***** TABLE 4: Panel Regressions 
***** using Quarterly Data
********************************

***Load data
clear all
use "data_formatting\quarterly_dataset.dta", clear
***


* column 1: not-weighted-overall-regression

xtreg c_ L.ABLQ  L(1/4).c_ q1 q2 q3 date_count, fe rob
nlcom _b[L.ABLQ]/(1-_b[L1.c_]-_b[L2.c_]-_b[L3.c_]-_b[L4.c_])

* column 2: weighted-overall-regression

areg c_ L.ABLQ  L(1/4).c_ q1 q2 q3 date_count [aweight=Bev_], absorb(group) rob
nlcom _b[L.ABLQ]/(1-_b[L1.c_]-_b[L2.c_]-_b[L3.c_]-_b[L4.c_])

* column 3: added workers only

preserve
drop if added_dummy==0

areg c_ L.ABLQ  L(1/4).c_ q1 q2 q3 date_count [aweight=Bev_], absorb(group) rob
nlcom _b[L.ABLQ]/(1-_b[L1.c_]-_b[L2.c_]-_b[L3.c_]-_b[L4.c_])

restore


* column 4: discouraged workers only
preserve
drop if reserve_dummy==0

areg c_ L.ABLQ  L(1/4).c_ q1 q2 q3 date_count [aweight=Bev_], absorb(group) rob
nlcom _b[L.ABLQ]/(1-_b[L1.c_]-_b[L2.c_]-_b[L3.c_]-_b[L4.c_])

restore



************************************
***** TABLE 5: Asymmetry Regressions 
***** before and after 2005
************************************

***Load data
use "data_formatting\yearly_dataset.dta", clear

* Drop Eastern-German, Non-German, Females between 60 and 64
* as well as Eastern-German, German, Males and Females between 55 and 59

drop if group == 10 | group == 42 | group == 31
***


gen dummy_bef = 0 
replace dummy_bef=1 if date < 2005

gen dummy_aft= 1- dummy_bef

gen intakt_bef = dummy_bef * ABLQ
gen intakt_aft = dummy_aft * ABLQ


**All unweighted

* column 1: All unweighted

xtreg c_ L.intakt_bef L.intakt_aft L.c_ , fe rob
nlcom _b[L.intakt_bef]/(1-_b[L.c_])
nlcom _b[L.intakt_aft]/(1-_b[L.c_])
nlcom (_b[L.intakt_bef]/(1-_b[L.c_]) - _b[L.intakt_aft]/(1-_b[L.c_]))

* column 2: All weighted


areg c_ L.intakt_bef L.intakt_aft L.c_ [aweight=Bev_], absorb(group) rob
nlcom _b[L.intakt_bef]/(1-_b[L.c_])
nlcom _b[L.intakt_aft]/(1-_b[L.c_])
nlcom (_b[L.intakt_bef]/(1-_b[L.c_]) - _b[L.intakt_aft]/(1-_b[L.c_]))

* column 3: added workers only

preserve 
drop if added_dummy==0
areg c_ L.intakt_bef L.intakt_aft L.c_ [aweight=Bev_], absorb(group) rob
nlcom _b[L.intakt_bef]/(1-_b[L.c_])
nlcom _b[L.intakt_aft]/(1-_b[L.c_])
nlcom (_b[L.intakt_bef]/(1-_b[L.c_]) - _b[L.intakt_aft]/(1-_b[L.c_]))
restore


* column 4: discouraged workers only

preserve 
drop if reserve_dummy==0
areg c_ L.intakt_bef L.intakt_aft L.c_ [aweight=Bev_], absorb(group) rob
nlcom _b[L.intakt_bef]/(1-_b[L.c_])
nlcom _b[L.intakt_aft]/(1-_b[L.c_])
nlcom (_b[L.intakt_bef]/(1-_b[L.c_]) - _b[L.intakt_aft]/(1-_b[L.c_]))
restore





******************************************************
******* Estimating the size of the discouraged workers
******************************************************

***Load data
use "data_formatting\yearly_dataset.dta", clear

* Drop Eastern-German, Non-German, Females between 60 and 64
* as well as Eastern-German, German, Males and Females between 55 and 59

drop if group == 10 | group == 42 | group == 31
***

drop if reserve_dummy == 0
statsby intsept=_b[_cons] sr_slope=_b[L.ABLQ] ar_slope=_b[L.c_] , by(group) saving(ols, replace) ///
 : xtreg c_ L.ABLQ L.c_, fe rob
merge group using ols
drop _merge
gen slope= sr_slope/(1-ar_slope)
gen discouraged_workers = 0
replace discouraged_workers = abs_Bev_ * (ABLQ - 2.5) * abs(slope) if date < 2005
replace discouraged_workers = abs_Bev_ * (ABLQ - 3.5) * abs(slope) if date > 2004
egen total_discouraged_workers = total(discouraged_workers), by (date)


************************************************
******* Estimating the size of the added workers
************************************************

***Load data
use "data_formatting\yearly_dataset.dta", clear

* Drop Eastern-German, Non-German, Females between 60 and 64
* as well as Eastern-German, German, Males and Females between 55 and 59

drop if group == 10 | group == 42 | group == 31
***


drop if added_dummy == 0
statsby intsept=_b[_cons] sr_slope=_b[L.ABLQ] ar_slope=_b[L.c_] , by(group) saving(ols, replace) ///
 : xtreg c_ L.ABLQ L.c_, fe rob
merge group using ols
drop _merge
gen slope = sr_slope/(1-ar_slope)
gen added_workers = 0
replace added_workers = abs_Bev_ * (ABLQ - 2.5) * abs(slope) if date < 2005
replace added_workers = abs_Bev_ * (ABLQ - 3.5) * abs(slope) if date > 2004
egen total_added_workers = total(added_workers), by (date)



